@@ -230,8 +230,8 @@ class Trivialscan:
         self, result_value: Union[bool, str, None], task: BaseEvaluationTask, **kwargs
     ) -> EvaluationResult:
         data = {
-            "rule_id": "%.3f" % task.metadata["rule_id"],
-            "group_id": "%.3f" % task.metadata["group_id"],
+            "rule_id": task.metadata["rule_id"],
+            "group_id": task.metadata["group_id"],
             "name": task.metadata["label_as"],
             "key": task.metadata["key"],
             "group": task.metadata["group"],
